@@ -1,9 +1,9 @@
 /***************************************************************************
-                          graph.h  -  description
+                                  graph.h
                              -------------------
     begin                : Sat Sep 29 2001
-    copyright            : (C) 2001 by Roland Riegel
-    email                : support@roland-riegel.de
+    copyright            : (C) 2001 - 2003 by Roland Riegel
+    email                : feedback@roland-riegel.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,9 +18,13 @@
 #ifndef GRAPH_H
 #define GRAPH_H
 
-#include <iostream.h>
-#include <curses.h>
 #include <list>
+using std::list;
+
+class Window;
+class OptionLong;
+
+const long STANDARD_MAX_DEFLECTION = 10240; // [kBit/s]  10 MBit/s = 10240 kBit/s
 
 class Graph
 {
@@ -31,22 +35,20 @@ public:
 	
 	void setNumOfBars( int );
 	void setHeightOfBars( int );
-	void setTrafficWithMaxDeflectionOfBars( int );
-	
-	void setWindow( WINDOW * );
+	void setTrafficWithMaxDeflectionOfBars( OptionLong* );
 	
 	void update( int );
-	void print( int, int );
+	void print( Window&, int, int );
 	void resetTrafficData();
 
 private:
+	long trafficWithMaxDeflectionOfBars();
+	
 	int m_heightofbars;
-	int m_trafficwithmaxdeflectionofbars;
+	OptionLong* m_trafficwithmaxdeflectionofbars;
 	
 	list<int> m_values;
 	
-	WINDOW *m_window;
-	
 };
 
 #endif
