@@ -2,8 +2,8 @@
                                    main.h
                              -------------------
     begin                : Wed Jul 25 2001
-    copyright            : (C) 2001 by Roland Riegel
-    email                : support@roland-riegel.de
+    copyright            : (C) 2001 - 2003 by Roland Riegel
+    email                : feedback@roland-riegel.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -15,21 +15,22 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-#include <iostream.h>
-#include <ctype.h>
-#include <time.h>
-#include <curses.h>
-#include <signal.h>
-#include <string>
-#include <vector>
-#include "dev.h"
+#ifndef MAIN_H
+#define MAIN_H
 
-using std::string;
-using std::vector;
+#include "traffic_window.h"
+#include "opt_window.h"
+
+int main( int argc, char *argv[] );
+
+void init();
+void finish();
+void end( int signal = 0 );
+void terminal_resized( int signal );
 
 void printhelp();
-void finish(int);
-int main(int, char **);
+
+OptWindow m_optwindow;
+TrafficWindow m_mainwindow;
+
+#endif
